@@ -23,7 +23,7 @@ CONF = cfg.CONF
 
 APARAMS = utils.get_agent_params()
 
-INSPECTION_DEFAULT_COLLECTOR = 'default'
+INSPECTION_DEFAULT_COLLECTOR = 'default,logs'
 INSPECTION_DEFAULT_DHCP_WAIT_TIMEOUT = 60
 
 cli_opts = [
@@ -36,6 +36,12 @@ cli_opts = [
                     'A special value "mdns" can be specified to fetch the '
                     'URL using multicast DNS service discovery.'),
 
+    cfg.StrOpt('global_request_id',
+               default=APARAMS.get('ipa-global-request-id'),
+               help='Global request ID header to provide to Ironic API. '
+                    'Can be supplied as "ipa-global-request-id" kernel '
+                    'parameter. The value must be in form "req-<UUID>".'),
+
     cfg.StrOpt('listen_host',
                default=APARAMS.get('ipa-listen-host',
                                    netutils.get_wildcard_address()),
@@ -48,6 +54,24 @@ cli_opts = [
                 help='The port to listen on. '
                      'Can be supplied as "ipa-listen-port" kernel parameter.'),
 
+    # This is intentionally not settable via kernel command line, as it
+    # requires configuration parameters from oslo_service which are not
+    # configurable over the command line and require files-on-disk.
+    # Operators who want to use this support should configure it statically
+    # as part of a ramdisk build.
+    cfg.BoolOpt('listen_tls',
+                default=False,
+                help='When true, IPA will host API behind TLS. You will also '
+                     'need to configure [ssl] group options for cert_file, '
+                     'key_file, and, if desired, ca_file to validate client '
+                     'certificates.'),
+
+    cfg.BoolOpt('enable_auto_tls',
+                default=True,
+                help='Enables auto-generating TLS parameters when listen_tls '
+                     'is False and ironic API version indicates support for '
+                     'automatic agent TLS.'),
+
     cfg.StrOpt('advertise_host',
                default=APARAMS.get('ipa-advertise-host', None),
                help='The host to tell Ironic to reply and send '
