@@ -185,7 +185,8 @@ class ISCSIExtension(base.BaseAgentExtension):
         if iqn is None:
             iqn = 'iqn.2008-10.org.openstack:%s' % uuidutils.generate_uuid()
 
-        device = hardware.dispatch_to_managers('get_os_install_device')
+        device = hardware.dispatch_to_managers('get_os_install_device',
+                                               permit_refresh=True)
 
         if wipe_disk_metadata:
             disk_utils.destroy_disk_metadata(
@@ -210,7 +211,8 @@ class ISCSIExtension(base.BaseAgentExtension):
         else:
             _start_lio(iqn, portal_port, device)
             LOG.debug('Linux-IO configuration: %s', rts_root.dump())
-
+        # Mark iscsi as previously started
+        self.agent.iscsi_started = True
         LOG.info('Created iSCSI target with iqn %(iqn)s, portal port %(port)d,'
                  ' on device %(dev)s using %(method)s',
                  {'iqn': iqn, 'port': portal_port, 'dev': device,
